// src/closestTo/closestTo.js
function closestTo(controlDate, args) {
  const cleanControlDate = Math.floor(new Date(controlDate).getTime());
  let closest;
  let closestIndex;
  let difference = 0;
  function assignValues(localDiff, closestDate, closestIdx) {
    difference = localDiff;
    closest = closestDate;
    closestIndex = closestIdx;
  }
  for (let i = 0; i < args.length; i++) {
    const localItem = Math.floor(new Date(args[i]).getTime());
    const localDifference = Math.abs(cleanControlDate - localItem);
    if (difference === 0) {
      assignValues(localDifference, args[i], i);
    } else {
      if (difference > localDifference) {
        assignValues(localDifference, args[i], i);
      }
    }
  }
  return { difference, closest, closestIndex };
}

// src/dateNow/dateNow.js
function dateNow(locale) {
  let output = String();
  if (locale) {
    output = new Date(Date.now()).toLocaleString(locale);
  } else {
    output = new Date(Date.now()).toLocaleString("en-CA");
  }
  return output;
}

// src/dateToUnix/dateToUnix.js
function dateToUnix(date) {
  let output;
  switch (typeof date) {
    case "object":
      output = Math.floor(date.getTime() / 1e3);
      break;
    case "string":
      output = Math.floor((new Date(date.split(",")[0]).getTime() + 8694e4) / 1e3);
      break;
    case "number":
      output = Math.floor(date / 1e3);
      break;
    default:
      output = "Error";
  }
  return output;
}

// src/daysFromNow/daysFromNow.js
function daysFromNow(multiplier, locale) {
  const twentyFourHours = Number(864e5);
  let output;
  if (locale?.length > 0) {
    output = new Date(Date.now() + Number(multiplier) * Number(twentyFourHours)).toLocaleString(locale);
  } else {
    output = new Date(Date.now() + Number(multiplier) * Number(twentyFourHours));
  }
  return output;
}

// src/getDaysInMonth/getDaysInMonth.js
function getDaysInMonth(monthIndex, year) {
  let month = Number();
  const monthObj = {
    jan: 0,
    feb: 1,
    mar: 2,
    apr: 3,
    may: 4,
    jun: 5,
    jul: 6,
    aug: 7,
    sep: 8,
    oct: 9,
    nov: 10,
    dec: 11
  };
  if (typeof year === "string" || typeof monthIndex === "string" || !monthIndex && !year) {
    if (monthIndex?.toString().toLowerCase() === "current" || year?.toString().toLowerCase() === "current" || !monthIndex && !year) {
      !year ? year = new Date().getFullYear() : year;
      month = new Date().getMonth();
    } else {
      let firstThree = String();
      if (monthIndex.length > 3) {
        firstThree = monthIndex.toString().toLowerCase().slice(0, 3);
      } else {
        firstThree = monthIndex;
      }
      month = monthObj[firstThree];
    }
  } else {
    month = Number(monthIndex);
  }
  return 32 - new Date(year, month, 32).getDate();
}

// src/getDuration/getDuration.js
function getDuration(firstDate, secondDate, measure) {
  const oneUnixYear = 31536e3;
  const firstDateUnix = dateToUnix(firstDate);
  const secondDateUnix = dateToUnix(secondDate);
  const difference = Math.abs(firstDateUnix - secondDateUnix);
  let output;
  switch (measure) {
    case "minutes":
      output = difference / oneUnixYear * 8760 * 60;
      break;
    case "hours":
      output = difference / oneUnixYear * 8760;
      break;
    case "days":
      output = difference / oneUnixYear * 365;
      break;
    case "weeks":
      output = difference / oneUnixYear * 52;
      break;
    case "months":
      output = difference / oneUnixYear * 12;
      break;
    case "years":
      output = difference / oneUnixYear;
      break;
    default:
      output = difference / oneUnixYear * 365;
  }
  return output;
}

// src/getMonthIndex/getMonthIndex.js
function getMonthIndex(monthName) {
  if (monthName === "current" || !monthName) {
    return new Date().getMonth();
  } else {
    const fullMonths = [
      "jan",
      "feb",
      "mar",
      "apr",
      "may",
      "jun",
      "jul",
      "aug",
      "sep",
      "oct",
      "nov",
      "dec"
    ];
    return fullMonths.indexOf(monthName.slice(0, 3).toLowerCase());
  }
}

// src/getTodayName/getTodayName.js
function getTodayName() {
  const fullDays = [
    "Sunday",
    "Monday",
    "Tuesday",
    "Wednesday",
    "Thursday",
    "Friday",
    "Saturday"
  ];
  return fullDays[new Date().getDay()].toLowerCase();
}

// src/getTomorrow/getTomorrow.js
function getTomorrow(locale) {
  const twentyFourHours = Number(864e5);
  if (locale) {
    return new Date(Date.now() + twentyFourHours).toLocaleString(locale);
  } else {
    return new Date(Date.now() + twentyFourHours).toLocaleString("en-CA");
  }
}

// src/getYear/getYear.js
function getYear() {
  return new Date().getFullYear();
}
export {
  closestTo,
  dateNow,
  dateToUnix,
  daysFromNow,
  getDaysInMonth,
  getDuration,
  getMonthIndex,
  getTodayName,
  getTomorrow,
  getYear
};
